"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeSdkAll = exports.writeSdkModel = void 0;
const path_1 = __importDefault(require("path"));
const entities_generation_1 = require("./model/entities-generation");
const services_generation_1 = require("./services/services-generation");
const queries_generation_1 = require("./services/queries-generation");
const cuba_model_utils_1 = require("../../../../../common/model/cuba-model-utils");
const pickMetadataFromProjectModel = (projectModel) => ({
    entities: cuba_model_utils_1.getAllEntities(projectModel).map(entity => ({
        name: entity.name,
        className: entity.className,
        persistentEntity: entity.persistentEntity,
        attributes: entity.attributes.map(attr => ({
            name: attr.name,
            type: attr.type,
            mappingType: attr.mappingType,
            cardinality: attr.cardinality,
            readOnly: attr.readOnly,
            mandatory: attr.mandatory,
            transient: attr.transient,
        })),
    })),
    enums: projectModel.enums.map(enumElem => ({
        className: enumElem.className,
        fqn: enumElem.fqn,
        values: enumElem.values,
    })),
});
function writeSdkModel(gen, model, destination) {
    return entities_generation_1.generateEntities(model, path_1.default.join(gen.destinationRoot(destination)), gen.fs);
}
exports.writeSdkModel = writeSdkModel;
function writeSdkAll(gen, model, destination) {
    const { restQueries, restServices } = model;
    const ctx = writeSdkModel(gen, model, destination);
    const services = services_generation_1.generateServices(restServices, ctx);
    const pathToWriteServices = gen.destinationPath('services.ts');
    gen.fs.write(pathToWriteServices, services);
    const queries = queries_generation_1.generateQueries(restQueries, ctx);
    const pathToWriteQueriess = gen.destinationPath('queries.ts');
    gen.fs.write(pathToWriteQueriess, queries);
    const metadata = pickMetadataFromProjectModel(model);
    const pathToWriteMetadata = gen.destinationPath('metadata.json');
    gen.fs.writeJSON(pathToWriteMetadata, metadata);
}
exports.writeSdkAll = writeSdkAll;
//# sourceMappingURL=sdk.js.map