"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const base_entity_screen_generator_1 = require("../../../../../generators/react-typescript/common/base-entity-screen-generator");
const test_utils_1 = require("../../../../common/test-utils");
const sinon = require("sinon");
const base_generator_1 = require("../../../../../common/base-generator");
const projectModel = require('../../../../fixtures/project-model--scr.json');
const projectModelNoIdAttr = require('../../../../fixtures/project-model--scr-no-id-attr.json');
const stringIdAnswers = require('../../../../fixtures/answers/string-id-management-table.js');
const stringIdAnswersExplicitIdName = require('../../../../fixtures/answers/string-id-management-table-explicit-id-name.json');
const stringIdAnswersNoIdName = require('../../../../fixtures/answers/string-id-management-table-no-id-name.json');
const stringIdAnswersUnexistentIdName = require('../../../../fixtures/answers/string-id-management-table-unexistent-id-name.json');
const intIdAnswers = require('../../../../fixtures/answers/int-id-management-table.json');
const listAttrsStringId = [
    {
        "name": "description",
        "type": {
            "packageName": "java.lang",
            "className": "String",
            "fqn": "java.lang.String",
            "label": "String"
        },
        "mappingType": "DATATYPE",
        "readOnly": false,
        "column": "DESCRIPTION",
        "mandatory": false,
        "unique": false,
        "length": 255,
        "transient": false
    }
];
const editAttrsStringId = [
    {
        "name": "description",
        "type": {
            "packageName": "java.lang",
            "className": "String",
            "fqn": "java.lang.String",
            "label": "String"
        },
        "mappingType": "DATATYPE",
        "readOnly": false,
        "column": "DESCRIPTION",
        "mandatory": false,
        "unique": false,
        "length": 255,
        "transient": false
    },
    {
        "name": "productCode",
        "type": {
            "packageName": "java.lang",
            "className": "String",
            "fqn": "java.lang.String",
            "label": "String"
        },
        "mappingType": "DATATYPE",
        "readOnly": false,
        "column": "PRODUCT_CODE",
        "mandatory": false,
        "unique": false,
        "length": 10,
        "transient": false
    },
];
const listAttrsIntId = listAttrsStringId.slice();
const editAttrsIntId = listAttrsIntId.slice();
const editAttrsImpostorId = [
    {
        "name": "id",
        "type": {
            "packageName": "java.lang",
            "className": "String",
            "fqn": "java.lang.String",
            "label": "String"
        },
        "mappingType": "DATATYPE",
        "readOnly": false,
        "column": "DESCRIPTION",
        "mandatory": false,
        "unique": false,
        "length": 255,
        "transient": false
    },
    {
        "name": "description",
        "type": {
            "packageName": "java.lang",
            "className": "String",
            "fqn": "java.lang.String",
            "label": "String"
        },
        "mappingType": "DATATYPE",
        "readOnly": false,
        "column": "DESCRIPTION",
        "mandatory": false,
        "unique": false,
        "length": 255,
        "transient": false
    }
];
const listIdPositionQuestion = {
    code: 'listIdAttrPos',
    caption: 'Position of the ID attribute in the List component ' +
        '(e.g. enter 1 for the ID to appear as the first row/column).',
    propertyType: "INTEGER" /* INTEGER */,
    required: true
};
const listShowIdQuestions = [
    {
        code: 'listShowIdAttr',
        caption: 'Show ID attribute in the List component?',
        propertyType: "BOOLEAN" /* BOOLEAN */,
        required: true
    }
];
const editIdPositionQuestion = {
    code: 'editIdAttrPos',
    caption: 'Position of the ID attribute in the Edit component ' +
        '(e.g. enter 1 for the ID to appear as the first field of the form).',
    propertyType: "INTEGER" /* INTEGER */,
    required: true
};
class TestEntityScreenGenerator extends base_generator_1.BaseGenerator {
    constructor(args, options) {
        super(args, options);
    }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    writing() { }
}
describe('BaseEntityScreenGenerator', () => {
    let gen;
    beforeEach(() => {
        gen = new TestEntityScreenGenerator([], { dirShift: '../../' });
    });
    it('getEntityFromAnswers() - no entity name', () => __awaiter(void 0, void 0, void 0, function* () {
        return test_utils_1.expectRejectedPromise(() => __awaiter(void 0, void 0, void 0, function* () { return base_entity_screen_generator_1.getEntityFromAnswers({ entity: {} }, projectModel); }), 'Additional prompt failed: cannot find entity name');
    }));
    it('getEntityFromAnswers() - unexisting entity name', () => __awaiter(void 0, void 0, void 0, function* () {
        return test_utils_1.expectRejectedPromise(() => __awaiter(void 0, void 0, void 0, function* () { return base_entity_screen_generator_1.getEntityFromAnswers({ entity: { name: 'Unexisting entity name' } }, projectModel); }), 'Additional prompt failed: cannot find entity');
    }));
    it('getEntityFromAnswers() - entity found', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = yield base_entity_screen_generator_1.getEntityFromAnswers({ entity: { name: 'scr$Car' } }, projectModel);
        chai_1.expect(entity.name).to.equal('scr$Car');
        chai_1.expect(entity.fqn).to.equal('com.company.scr.entity.Car');
    }));
    it('stringIdPrompts() - not a String ID entity', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = projectModel.entities.find((e) => e.name === 'scr_IntegerIdTestEntity');
        sinon.stub(gen, 'prompt').callsFake(createPromptFake());
        const answers = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion);
        chai_1.expect(answers).to.deep.equal({});
    }));
    it('stringIdPrompts() - String ID entity, no ID attribute name in project model (older Studio)', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = projectModelNoIdAttr.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        sinon.stub(gen, 'prompt').callsFake(createPromptFake());
        const answers = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion);
        chai_1.expect(answers.idAttrName).to.equal('test_identifier');
    }));
    it('stringIdPrompts() - String ID entity with ID attribute name in project model', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        sinon.stub(gen, 'prompt').callsFake(createPromptFake());
        const answers = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion);
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(answers.idAttrName).to.be.undefined;
    }));
    it('stringIdPrompts() - String ID entity, questions about showing ID', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        sinon.stub(gen, 'prompt').callsFake(createPromptFake());
        const answers = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion);
        chai_1.expect(answers.listShowIdAttr).to.equal(true);
        chai_1.expect(answers.listIdAttrPos).to.equal(42);
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(answers.editIdAttrPos).to.be.undefined;
        // @ts-ignore unwrap the spy
        gen.prompt.restore();
        sinon.stub(gen, 'prompt').callsFake(createPromptFake({
            listShowIdAttr: false
        }));
        const answers2 = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion);
        chai_1.expect(answers2.listShowIdAttr).to.equal(false);
        chai_1.expect(answers2.listIdAttrPos).to.equal(undefined);
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(answers.editIdAttrPos).to.be.undefined;
    }));
    it('_stringIdPrompts() - String ID entity, with Edit component', () => __awaiter(void 0, void 0, void 0, function* () {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        sinon.stub(gen, 'prompt').callsFake(createPromptFake());
        const answers = yield base_entity_screen_generator_1.stringIdPrompts(gen, entity, projectModel, listShowIdQuestions, listIdPositionQuestion, editIdPositionQuestion);
        chai_1.expect(answers.editIdAttrPos).to.equal(42);
    }));
});
describe('stringIdAnswersToModel()', () => {
    // TODO not supported yet
    xit('should return correct result for a String ID entity', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        const { stringIdName, listAttributes, editAttributes } = base_entity_screen_generator_1.stringIdAnswersToModel(stringIdAnswers, projectModel, entity, listAttrsStringId, editAttrsStringId);
        chai_1.expect(stringIdName).to.equal('identifier');
        chai_1.expect(listAttributes[1].name).to.equal('identifier');
        chai_1.expect(editAttributes[1].name).to.equal('identifier');
    });
    it('should return correct result for a String ID entity ' +
        'when ID attribute name is not in project model', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        const { stringIdName, listAttributes, editAttributes } = base_entity_screen_generator_1.stringIdAnswersToModel(stringIdAnswersExplicitIdName, projectModel, entity, listAttrsStringId, editAttrsStringId);
        chai_1.expect(stringIdName).to.equal('identifier');
        chai_1.expect(listAttributes[1].name).to.equal('identifier');
        chai_1.expect(editAttributes[1].name).to.equal('identifier');
    });
    it('should return correct result for an entity that is not a String ID entity', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_IntegerIdTestEntity');
        const { stringIdName, listAttributes, editAttributes } = base_entity_screen_generator_1.stringIdAnswersToModel(intIdAnswers, projectModel, entity, listAttrsIntId, editAttrsIntId);
        // tslint:disable-next-line:no-unused-expression
        chai_1.expect(stringIdName).to.be.undefined;
        chai_1.expect(listAttributes.length).to.equal(1);
        chai_1.expect(listAttributes[0].name).to.equal('description');
        chai_1.expect(editAttributes.length).to.equal(1);
        chai_1.expect(editAttributes[0].name).to.equal('description');
    });
    it('should throw if String ID name is neither in the project model nor in the answers', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        chai_1.expect(() => base_entity_screen_generator_1.stringIdAnswersToModel(stringIdAnswersNoIdName, projectModel, entity, listAttrsStringId, editAttrsStringId)).to.throw('Could not find the stringIdName');
    });
    it('should throw if ID attribute does not exist', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        chai_1.expect(() => base_entity_screen_generator_1.stringIdAnswersToModel(stringIdAnswersUnexistentIdName, projectModel, entity, listAttrsStringId, editAttrsStringId)).to.throw('Unable to find ID attribute. Expected the ID attribute to be named "dientifire".');
    });
    // TODO not supported yet
    xit('should return correct result for a String ID entity that has a non-ID attribute named `id`', () => {
        const entity = projectModel.entities.find((e) => e.name === 'scr_StringIdTestEntity');
        const { editAttributes } = base_entity_screen_generator_1.stringIdAnswersToModel(stringIdAnswers, projectModel, entity, listAttrsStringId, editAttrsImpostorId);
        chai_1.expect(editAttributes.length).to.equal(2);
        chai_1.expect(editAttributes[1].name).to.equal('identifier');
    });
});
function createPromptFake(result = {}) {
    return (questions) => {
        const answers = {};
        questions.forEach((question) => {
            var _a, _b, _c, _d;
            switch (question.name) {
                case 'idAttrName':
                    answers.idAttrName = (_a = result.idAttrName) !== null && _a !== void 0 ? _a : 'test_identifier';
                    break;
                case 'listShowIdAttr':
                    answers.listShowIdAttr = (_b = result.listShowIdAttr) !== null && _b !== void 0 ? _b : true;
                    break;
                case 'listIdAttrPos':
                    answers.listIdAttrPos = (_c = result.listIdAttrPos) !== null && _c !== void 0 ? _c : 42;
                    break;
                case 'editIdAttrPos':
                    answers.editIdAttrPos = (_d = result.editIdAttrPos) !== null && _d !== void 0 ? _d : 42;
                    break;
            }
        });
        return Promise.resolve(answers);
    };
}
//# sourceMappingURL=index.test.js.map