"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const studio_integration_1 = require("../common/studio/studio-integration");
const chai_1 = require("chai");
const nock = require("nock");
const fs_1 = __importDefault(require("fs"));
describe('studio-integration', function () {
    //to check integration with real run studio set CI_MODE = false
    const CI_MODE = true;
    before(() => {
        //mock request to studio on CI
        if (CI_MODE) {
            nock('http://localhost:48561')
                .get(/\?printCubaProjects.*/)
                .reply(200, [{ 'name': 'model-playground', 'path': '/model-playground', 'locationHash': 'd50df17f' }])
                .get(/\?exportModelProjectDest.*/)
                .reply(200, '');
        }
    });
    it('exports model', function () {
        this.timeout(20000);
        //todo move dest to src/test/generated/studio
        const dest = path_1.default.join(process.cwd(), '.tmp/projectModel.json');
        !CI_MODE && fs_1.default.truncateSync(dest);
        studio_integration_1.exportProjectModel("d50df17f", dest)
            .then(() => {
            !CI_MODE && chai_1.expect(fs_1.default.statSync(dest).size).greaterThan(0);
        });
    });
    it('prints cuba projects', function () {
        studio_integration_1.getOpenedCubaProjects()
            .then((projects) => {
            CI_MODE ?
                chai_1.expect(projects && projects[0].locationHash === 'd50df17f')
                : console.log(JSON.stringify(projects));
        });
    });
    it('should normalize secret', () => {
        let secret = studio_integration_1.normalizeSecret('{noop}bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        chai_1.expect(secret).eq('bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        secret = studio_integration_1.normalizeSecret('{}bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        chai_1.expect(secret).eq('bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        secret = studio_integration_1.normalizeSecret('{21879*&*^7ydtwuydtwqy}bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        chai_1.expect(secret).eq('bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        secret = studio_integration_1.normalizeSecret('bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
        chai_1.expect(secret).eq('bf37f38be32f307c4fc5b2c1517cac2984ea46eaf6856dfa56cfe92212ee26c9');
    });
});
//# sourceMappingURL=studio-integration.test.js.map