"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../common/utils");
const assert_1 = __importDefault(require("assert"));
const chai_1 = require("chai");
describe('utils', () => {
    it("elementNameToClass", () => {
        assert_1.default.strictEqual(utils_1.elementNameToClass('my-custom-el'), 'MyCustomEl');
        assert_1.default.strictEqual(utils_1.elementNameToClass('x-f'), 'XF');
        assert_1.default.strictEqual(utils_1.elementNameToClass('myCustomEl'), 'MyCustomEl');
        assert_1.default.strictEqual(utils_1.elementNameToClass('my custom El'), 'MyCustomEl');
        assert_1.default.strictEqual(utils_1.elementNameToClass('  my   veryCustom  El   '), 'MyVeryCustomEl');
        assert_1.default.strictEqual(utils_1.elementNameToClass('~!@#%^&*()_+the Cla$$'), '_theCla$$');
    });
    it(utils_1.convertToUnixPath.name, () => {
        assert_1.default.strictEqual(utils_1.convertToUnixPath('.\\some\\path'), './some/path');
    });
    it('should convert fqn name to valid TS class name ', () => {
        assert_1.default.strictEqual(utils_1.fqnToName('com.company.mpg.entity.CarType'), 'com_company_mpg_entity_CarType');
        assert_1.default.strictEqual(utils_1.fqnToName(''), '');
    });
    it('should split string by capital letter', () => {
        chai_1.expect(utils_1.splitByCapitalLetter('splitByCapital')).eq('split By Capital');
        chai_1.expect(utils_1.splitByCapitalLetter('SplitByCapital')).eq('Split By Capital');
        chai_1.expect(utils_1.splitByCapitalLetter('split123It')).eq('split123 It');
        chai_1.expect(utils_1.splitByCapitalLetter('split$It')).eq('split$ It');
        chai_1.expect(utils_1.splitByCapitalLetter('split_It')).eq('split_ It');
    });
    it('should normalize relative path', () => {
        chai_1.expect(utils_1.normalizeRelativePath("..")).eq("../");
        chai_1.expect(utils_1.normalizeRelativePath("../")).eq("../");
        chai_1.expect(utils_1.normalizeRelativePath("../..")).eq("../../");
        chai_1.expect(utils_1.normalizeRelativePath("../../")).eq("../../");
        chai_1.expect(utils_1.normalizeRelativePath("")).eq("");
        chai_1.expect(utils_1.normalizeRelativePath(".")).eq("./");
        chai_1.expect(utils_1.normalizeRelativePath("./")).eq("./");
        chai_1.expect(utils_1.normalizeRelativePath("./../")).eq("../");
        chai_1.expect(utils_1.normalizeRelativePath("/")).eq("/");
        chai_1.expect(utils_1.normalizeRelativePath("   ")).eq("");
        chai_1.expect(utils_1.normalizeRelativePath(undefined)).eq("");
    });
});
//# sourceMappingURL=utils.test.js.map